@@ -82,10 +82,10 @@ bool WordPerfectCollector::filter(GsfInput *pInput, GsfOutfile *pOutfile)
 	}
 	
 	WRITER_DEBUG_MSG(("Destroying the rest of the styles elements\n"));
-	for (map<const UTF8String, TextRunStyle *>::iterator iter = mParagraphStyleHash.begin(); iter != mParagraphStyleHash.end(); iter++) {
+	for (map<UTF8String, TextRunStyle *>::iterator iter = mParagraphStyleHash.begin(); iter != mParagraphStyleHash.end(); iter++) {
 		delete(iter->second);
 	}
-	for (map<const UTF8String, FontStyle *>::iterator iter = mFontHash.begin(); iter != mFontHash.end(); iter++) {
+	for (map<UTF8String, FontStyle *>::iterator iter = mFontHash.begin(); iter != mFontHash.end(); iter++) {
 		delete(iter->second);
 	}
 
@@ -257,7 +257,7 @@ bool WordPerfectCollector::_writeTargetDocument(GsfOutfile *pOutfile)
 
 	// write out the font styles
 	gsf_output_printf (pContentChild, "<office:font-decls>\n");
-	for (map<const UTF8String, FontStyle *>::iterator iter = mFontHash.begin(); iter != mFontHash.end(); iter++) {
+	for (map<UTF8String, FontStyle *>::iterator iter = mFontHash.begin(); iter != mFontHash.end(); iter++) {
 		iter->second->write(pContentChild);
 	}
 	TagOpenElement symbolFontOpen("style:font-decl");
@@ -274,7 +274,7 @@ bool WordPerfectCollector::_writeTargetDocument(GsfOutfile *pOutfile)
 
 	// write automatic styles: which encompasses quite a bit
        	gsf_output_printf (pContentChild, "<office:automatic-styles>\n");
-	for (map<const UTF8String, TextRunStyle *>::iterator iter = mParagraphStyleHash.begin(); iter != mParagraphStyleHash.end(); iter++) {
+	for (map<UTF8String, TextRunStyle *>::iterator iter = mParagraphStyleHash.begin(); iter != mParagraphStyleHash.end(); iter++) {
 		// writing out the paragraph styles
 		if (strcmp((iter->second)->getName()->str, "Standard") || 
 		    !(dynamic_cast<ParagraphStyle *>(iter->second))) { 
@@ -352,9 +352,9 @@ ParagraphStyle * WordPerfectCollector::_requestParagraphStyle(const guint8 iPara
 	WRITER_DEBUG_MSG(("WriterWordPerfect: Else.. (mbFirstElement=%i)", mWriterDocumentState.mbFirstElement));
 
 	UTF8String sParagraphHashKey;
-	sParagraphHashKey.sprintf("P|%s|%i|%i|%f|%f|%s|%f|%f|%i|%i", pParentName, iParagraphJustification, iTextAttributeBits,
-				     fMarginLeft, fMarginRight, pFontName, fFontSize, fLineSpacing, bColumnBreak, bPageBreak);
-	WRITER_DEBUG_MSG(("WriterWordPerfect: P|%s|%i|%i|%f|%f|%s|%f|%f|%i|%i|%s|%s\n", pParentName, iParagraphJustification, iTextAttributeBits, fMarginLeft, fMarginRight, pFontName, fFontSize, fLineSpacing, bColumnBreak, bPageBreak, pParentName, pName));
+	sParagraphHashKey.sprintf("P|%s|%i|%f|%f|%f|%i|%i", pParentName, iParagraphJustification,
+				     fMarginLeft, fMarginRight, fLineSpacing, bColumnBreak, bPageBreak);
+	WRITER_DEBUG_MSG(("WriterWordPerfect: P|%s|%i|%f|%f|%f|%i|%i|%s|%s\n", pParentName, iParagraphJustification, fMarginLeft, fMarginRight,  fLineSpacing, bColumnBreak, bPageBreak, pParentName, pName));
 	WRITER_DEBUG_MSG(("WriterWordPerfect: Paragraph Hash Key: %s\n", sParagraphHashKey.getUTF8()));
 
 	// Get the style
@@ -939,10 +939,16 @@ void WordPerfectCollector::closeTable()
 	mpCurrentContentElements->push_back(static_cast<DocumentElement *>(new TagCloseElement("table:table")));			
 }
 
+void WordPerfectCollector::insertLineBreak()
+{
+	WRITER_DEBUG_MSG(("WriterWordPerfect: Insert Line Break\n"));
+	mpCurrentContentElements->push_back(static_cast<DocumentElement *>(new TagOpenElement("text:line-break")));			
+	mpCurrentContentElements->push_back(static_cast<DocumentElement *>(new TagCloseElement("text:line-break")));			
+}
 
 void WordPerfectCollector::insertTab()
 {
-	WRITER_DEBUG_MSG(("WriterWordPerfect: Insert Text\n"));
+	WRITER_DEBUG_MSG(("WriterWordPerfect: Insert Tab\n"));
 	mpCurrentContentElements->push_back(static_cast<DocumentElement *>(new TagOpenElement("text:tab-stop")));			
 	mpCurrentContentElements->push_back(static_cast<DocumentElement *>(new TagCloseElement("text:tab-stop")));			
 }
